Complete.Org: Mailing Lists: Archives: freeciv-dev: March 2003:
[Freeciv-Dev] Re: (PR#3586) More spelling fixes
Home

[Freeciv-Dev] Re: (PR#3586) More spelling fixes

[Top] [All Lists]

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index] [Thread Index]
To: undisclosed-recipients:;
Subject: [Freeciv-Dev] Re: (PR#3586) More spelling fixes
From: "Raimar Falke" <rf13@xxxxxxxxxxxxxxxxx>
Date: Wed, 5 Mar 2003 14:24:37 -0800
Reply-to: rt@xxxxxxxxxxxxxx

On Wed, Mar 05, 2003 at 12:54:17AM -0800, Jason Short wrote:
> It doesn't look like it's made any incorrect changes, 

> but it's certainly missed a lot.  For instance, it catches
> "transfering" but not "transfered".  (No, "transfere" isn't a word.)

You have to tell it what it should do. It is more like a recursive
sed. You have to specify the from and to versions.

I have added your "transfered" correction from above and added
helpdata.txt.

If you have more common mistakes please tell me.

        Raimar

-- 
 email: rf13@xxxxxxxxxxxxxxxxx
  "Heuer's Law: Any feature is a bug unless it can be turned off."

Index: data/helpdata.txt
===================================================================
RCS file: /home/freeciv/CVS/freeciv/data/helpdata.txt,v
retrieving revision 1.118
diff -u -u -r1.118 helpdata.txt
--- data/helpdata.txt   2003/02/10 22:49:28     1.118
+++ data/helpdata.txt   2003/03/05 22:20:33
@@ -713,7 +713,7 @@
      Of course, the owner of that city can still give it to \
 you, in which case the area around the city is shown \
 on your map.  One important thing to note: any units \
-in the field and supported by that city are also transfered \
+in the field and supported by that city are also transferred \
 (but not those sitting in other cities).  So make sure the \
 other player isn't getting a better deal than you expect.\
 ")
Index: server/cityturn.c
===================================================================
RCS file: /home/freeciv/CVS/freeciv/server/cityturn.c,v
retrieving revision 1.207
diff -u -u -r1.207 cityturn.c
--- server/cityturn.c   2003/02/27 22:15:18     1.207
+++ server/cityturn.c   2003/03/05 22:20:35
@@ -1380,7 +1380,7 @@
   /* shift all the units supported by pcity (including the new unit)
      to rcity.  transfer_city_units does not make sure no units are
      left floating without a transport, but since all units are
-     transfered this is not a problem. */
+     transferred this is not a problem. */
   transfer_city_units(pplayer, pplayer, &pcity->units_supported, rcity, pcity, 
-1, TRUE);
 
   notify_player_ex(pplayer, x, y, E_UNIT_BUILD,

[Prev in Thread] Current Thread [Next in Thread]
Index: server/citytools.c
===================================================================
RCS file: /home/freeciv/CVS/freeciv/server/citytools.c,v
retrieving revision 1.213
diff -u -u -r1.213 citytools.c
--- server/citytools.c  2003/03/05 08:56:08     1.213
+++ server/citytools.c  2003/03/05 22:20:35
@@ -615,10 +615,10 @@
 
 pplayer: The player recieving the units if they are not disbanded and
          are not in a city
-pvictim: The owner of the city the units are transfered from.
-units:   A list of units to be transfered, typically a cities unit list.
-pcity:   Default city the units are transfered to.
-exclude_city: The units cannot be transfered to this city.
+pvictim: The owner of the city the units are transferred from.
+units:   A list of units to be transferred, typically a cities unit list.
+pcity:   Default city the units are transferred to.
+exclude_city: The units cannot be transferred to this city.
 kill_outside: Units outside this range are deleted. -1 means no units
               are deleted.
 verbose: Messages are sent to the involved parties.
@@ -668,7 +668,7 @@
       transfer_unit(vunit, pcity, verbose);
     }
 
     /* not deleting cargo as it may be carried by units transfered later.
        no cargo deletion => no trouble with "units" list.
        In cases where the cargo can be left without transport the calling
        function should take that into account. */
@@ -765,7 +765,7 @@
   struct city *pnew_capital;
 
   if (size == 0) {
     /* The last city was removed or transfered to the enemy. R.I.P. */
     return;
   }
 
@@ -899,7 +899,7 @@
 
   /*
    * Give the new owner infos about all cities which have a traderoute
    * with the transfered city.
    */
   for (i = 0; i < NUM_TRADEROUTES; i++) {
     struct city *pother_city = find_city_by_id(pcity->trade[i]);
@@ -668,7 +668,7 @@
     }
 
-    /* not deleting cargo as it may be carried by units transfered later.
+    /* not deleting cargo as it may be carried by units transferred later.
        no cargo deletion => no trouble with "units" list.
        In cases where the cargo can be left without transport the calling
@@ -765,7 +765,7 @@
 
   if (size == 0) {
-    /* The last city was removed or transfered to the enemy. R.I.P. */
+    /* The last city was removed or transferred to the enemy. R.I.P. */
     return;
   }
@@ -899,7 +899,7 @@
   /*
    * Give the new owner infos about all cities which have a traderoute
-   * with the transfered city.
+   * with the transferred city.
    */
   for (i = 0; i < NUM_TRADEROUTES; i++) {